@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0107';
 
 use strict;
 use warnings;
@@ -106,7 +106,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0106
+version 0.0107
 
 =head1 SYNOPSIS
 
@@ -114,10 +114,10 @@ version 0.0106
 
   my $mcg = MIDI::Chord::Guitar->new;
 
-  my $transformed = $mcg->transform('D3', 'dim7', 0);
+  my $chord = $mcg->transform('D3', 'dim7', 0);
 
   # MIDI:
-  #$score->n('wn', @$transformed);
+  #$score->n('wn', @$chord);
 
 =head1 DESCRIPTION
 
@@ -180,15 +180,15 @@ Return the guitar chord data filename location.
 
 =head2 transform
 
-  $transformed = $mcg->transform($target, $chord_name, $variation);
+  $chord = $mcg->transform($target, $chord_name, $variation);
 
 Find the chord given the B<target>, B<chord_name> and B<variation>.
 
 The B<target> must be in the format of an C<ISO> note (e.g. on the
 guitar, a C note is represented by C<C3>, C<C4>, C<C5>, etc).
 
-There is no logic to the order of the voicing variations of a chord.
-Please use the above diagrams to figure out the neck positions.
+If no B<chord_name> is given, C<major> is used.  If no B<variation> is
+given, C<0> is used.
 
 =head2 voicings
 
@@ -196,6 +196,10 @@ Please use the above diagrams to figure out the neck positions.
 
 Return all the voicings of a given B<chord_name>.
 
+The order of the voicing variations of a chord is by fret position.
+So, the first variations are at lower frets.  Please use the above
+diagrams to figure out the exact neck positions.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> file in this distribution
